package com.qianhe.service;

import com.qianhe.domain.SjGfjsZsdwwtcj;

import java.util.List;

/**
 * 规范建设-直属单位问题采集Service接口
 * 
 * @author qianhe
 * @date 2024-07-23
 */
public interface ISjGfjsZsdwwtcjService 
{
    /**
     * 查询规范建设-直属单位问题采集
     * 
     * @param id 规范建设-直属单位问题采集主键
     * @return 规范建设-直属单位问题采集
     */
    public SjGfjsZsdwwtcj selectSjGfjsZsdwwtcjById(Long id);

    /**
     * 查询规范建设-直属单位问题采集列表
     * 
     * @param sjGfjsZsdwwtcj 规范建设-直属单位问题采集
     * @return 规范建设-直属单位问题采集集合
     */
    public List<SjGfjsZsdwwtcj> selectSjGfjsZsdwwtcjList(SjGfjsZsdwwtcj sjGfjsZsdwwtcj);

    /**
     * 新增规范建设-直属单位问题采集
     * 
     * @param sjGfjsZsdwwtcj 规范建设-直属单位问题采集
     * @return 结果
     */
    public int insertSjGfjsZsdwwtcj(SjGfjsZsdwwtcj sjGfjsZsdwwtcj);

    /**
     * 修改规范建设-直属单位问题采集
     * 
     * @param sjGfjsZsdwwtcj 规范建设-直属单位问题采集
     * @return 结果
     */
    public int updateSjGfjsZsdwwtcj(SjGfjsZsdwwtcj sjGfjsZsdwwtcj);
    public int plxg(SjGfjsZsdwwtcj sjGfjsZsdwwtcj);

    /**
     * 批量删除规范建设-直属单位问题采集
     * 
     * @param ids 需要删除的规范建设-直属单位问题采集主键集合
     * @return 结果
     */
    public int deleteSjGfjsZsdwwtcjByIds(Long[] ids);

    /**
     * 删除规范建设-直属单位问题采集信息
     * 
     * @param id 规范建设-直属单位问题采集主键
     * @return 结果
     */
    public int deleteSjGfjsZsdwwtcjById(Long id);

    int batchSave(List<SjGfjsZsdwwtcj> list);

}
